@@ -35,14 +35,15 @@ class CustomComplianceConfigAPI(object):
 
         logger.info("Getting custom compliance settings from Lacework...")
 
-        # Build the Run Report request URI
+        # Build the Custom Compliance Config request URI
         api_uri = "/api/v1/external/CustomComplianceConfig"
 
         response = self._session.get(api_uri)
 
         return response.json()
 
-    def set(self, data):
+    def set(self,
+            data):
         """
         A method to set the custom compliance settings in Lacework.
 
@@ -53,7 +54,7 @@ class CustomComplianceConfigAPI(object):
 
         logger.info("Setting custom compliance settings in Lacework...")
 
-        # Build the Run Report request URI
+        # Build the Custom Compliance Config request URI
         api_uri = "/api/v1/external/CustomComplianceConfig"
 
         response = self._session.post(api_uri, data=data)
