@@ -3,6 +3,7 @@
 Test suite for the community-developed Python SDK for interacting with Lacework APIs.
 """
 
+import logging
 import os
 
 import laceworksdk
@@ -10,6 +11,8 @@ import pytest
 
 from dotenv import load_dotenv
 
+logging.basicConfig(level=logging.DEBUG)
+
 load_dotenv()
 
 
@@ -31,15 +34,22 @@ def account():
 
 
 @pytest.fixture(scope="session")
-def api_old(api_key, api_secret, account):
-    return laceworksdk.LaceworkClient(api_key=api_key,
-                                      api_secret=api_secret,
-                                      instance=account)
+def subaccount():
+    return os.getenv("LW_SUBACCOUNT")
 
 
 @pytest.fixture(scope="session")
-def api(account, api_key, api_secret):
+def api_old(account, subaccount, api_key, api_secret):
+    return laceworksdk.LaceworkClient(instance=account,
+                                      subaccount=subaccount,
+                                      api_key=api_key,
+                                      api_secret=api_secret)
+
+
+@pytest.fixture(scope="session")
+def api(account, subaccount, api_key, api_secret):
     return laceworksdk.LaceworkClient(account=account,
+                                      subaccount=subaccount,
                                       api_key=api_key,
                                       api_secret=api_secret)
 
